﻿using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using Mirea.Api.DataAccess.Domain.Schedule;

namespace Mirea.Api.DataAccess.Persistence.EntityTypeConfigurations.Schedule;

public class DayConfiguration : IEntityTypeConfiguration<Day>
{
    public void Configure(EntityTypeBuilder<Day> builder)
    {
        builder.ToTable(nameof(Day));
        builder.HasKey(d => d.Id);
        builder.HasIndex(d => d.Id).IsUnique();
        builder.Property(d => d.Id).HasColumnType("INTEGER").IsRequired().ValueGeneratedOnAdd();

        builder.Property(d => d.PairNumber).HasColumnType("INTEGER").IsRequired();
        builder.Property(d => d.Index).HasColumnType("INTEGER").IsRequired();
        builder.Property(d => d.GroupId).HasColumnType("INTEGER").IsRequired();
        builder.Property(d => d.LessonId).HasColumnType("INTEGER").IsRequired();

        builder
            .HasOne(d => d.Group)
            .WithMany(g => g.Days)
            .HasForeignKey(d => d.GroupId)
            .OnDelete(DeleteBehavior.Restrict);
        builder
            .HasOne(d => d.Lesson)
            .WithOne(l => l.Day)
            .HasForeignKey<Day>(d => d.LessonId)
            .OnDelete(DeleteBehavior.Restrict);
    }
}