﻿using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using Mirea.Api.DataAccess.Domain.Schedule;

namespace Mirea.Api.DataAccess.Persistence.EntityTypeConfigurations.Schedule;

public class LessonToTypeOfOccupationConfiguration : IEntityTypeConfiguration<LessonToTypeOfOccupation>
{
    public void Configure(EntityTypeBuilder<LessonToTypeOfOccupation> builder)
    {
        builder.ToTable(nameof(LessonToTypeOfOccupation));
        builder.HasKey(l => l.Id);
        builder.HasIndex(l => l.Id).IsUnique();
        builder.Property(l => l.Id).HasColumnType("INTEGER").IsRequired().ValueGeneratedOnAdd();

        builder.Property(l => l.LessonId).HasColumnType("INTEGER").IsRequired();
        builder.Property(l => l.TypeOfOccupationId).HasColumnType("INTEGER").IsRequired();

        builder
            .HasOne(l => l.Lesson)
            .WithMany(l => l.TypeOfOccupations)
            .HasForeignKey(l => l.LessonId)
            .OnDelete(DeleteBehavior.Cascade);

        builder
            .HasOne(l => l.TypeOfOccupation)
            .WithMany(t => t.Lessons)
            .HasForeignKey(l => l.TypeOfOccupationId)
            .OnDelete(DeleteBehavior.Cascade);
    }
}