﻿using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using Mirea.Api.DataAccess.Domain.Schedule;

namespace Mirea.Api.DataAccess.Persistence.EntityTypeConfigurations.Schedule;

public class ProfessorToLessonConfiguration : IEntityTypeConfiguration<ProfessorToLesson>
{
    public void Configure(EntityTypeBuilder<ProfessorToLesson> builder)
    {
        builder.ToTable(nameof(ProfessorToLesson));
        builder.HasKey(p => p.Id);
        builder.HasIndex(p => p.Id).IsUnique();
        builder.Property(p => p.Id).HasColumnType("INTEGER").IsRequired().ValueGeneratedOnAdd();

        builder.Property(l => l.LinkToMeet).HasColumnType("TEXT").HasMaxLength(512);
        builder.Property(p => p.LessonId).HasColumnType("INTEGER").IsRequired();
        builder.Property(p => p.ProfessorId).HasColumnType("INTEGER");
        builder.Property(l => l.LectureHallId).HasColumnType("INTEGER");

        builder
            .HasOne(p => p.LectureHall)
            .WithMany(l => l.ProfessorToLessons)
            .HasForeignKey(l => l.LectureHallId)
            .OnDelete(DeleteBehavior.SetNull);

        builder
            .HasOne(p => p.Lesson)
            .WithMany(l => l.ProfessorToLesson)
            .HasForeignKey(p => p.LessonId)
            .OnDelete(DeleteBehavior.Cascade);

        builder
            .HasOne(p => p.Professor)
            .WithMany(p => p.ProfessorToLesson)
            .HasForeignKey(p => p.ProfessorId)
            .OnDelete(DeleteBehavior.Cascade);
    }
}